@@ -617,6 +617,9 @@ class DragonGather(TaskScheduler):
                     "PD_TO1: Tiempo fuera para conectar db source %s" % rc)
                 kwargs["origin_exception"] = "PD_TO1_00 + %s" % code
                 self.rethinkdb_origin[ids] = False
+                rc.close()
+                del rc
+                rc=None
                 return [ipt, ids, v,
                         [di, control, (rc, rc_enu),
                          process_data]], kwargs
@@ -646,6 +649,9 @@ class DragonGather(TaskScheduler):
                 kwargs["origin_exception"] = "PD_TO1_00 + %s" % code
                 self.rethinkdb_origin_enu[ids] = False
                 bprint(kwargs)
+                rc_enu.close()
+                del rc_enu
+                rc_enu=None
                 return [ipt, ids, v,
                         [di, control, (rc, rc_enu),
                          process_data]], kwargs
@@ -671,6 +677,9 @@ class DragonGather(TaskScheduler):
                 kwargs["origin_exception"] = "PD_TO3_00 + %s" % code
                 self.rethinkdb_origin[ids] = False
                 bprint(kwargs)
+                rc.close()
+                del rc
+                rc=None
                 wargs = [ipt, ids, v, [
                     di, control, (rc, rc_enu), process_data]]
                 return wargs, kwargs
@@ -681,6 +690,9 @@ class DragonGather(TaskScheduler):
                     "Error en la obtención de datos para estación %s en %s" % (code, di))
                 kwargs["origin_exception"] = "PD_TO4_00 + %s" % code
                 self.rethinkdb_origin[ids] = False
+                rc.close()
+                del rc
+                rc=None
                 wargs = [ipt, ids, v, [
                     di, control, (rc, rc_enu), process_data]]
                 return wargs, kwargs
@@ -728,6 +740,9 @@ class DragonGather(TaskScheduler):
                             "PD_TO3: Tiempo fuera para conectar db %s, al leer datos desde db" % rc)
                         kwargs["origin_exception"] = "PD_TO5_01 + %s" % code
                         self.rethinkdb_origin_enu[ids] = False
+                        rc_enu.close()
+                        del rc_enu
+                        rc_enu = None
                         wargs = [ipt, ids, v, [
                             di, control, (rc, rc_enu), process_data]]
                         return wargs, kwargs
@@ -736,6 +751,9 @@ class DragonGather(TaskScheduler):
                               (code, ex), flush=True)
                         kwargs["origin_exception"] = "PD_TO5_02 + %s" % code
                         bprint(kwargs)
+                        rc_enu.close()
+                        del rc_enu
+                        rc_enu = None
                         return [ipt, ids, v,
                                 [di, control,
                                  (rc, rc_enu),
