@@ -181,13 +181,11 @@ def start_datawork(env, conf="collector_example.json"):
         # create gui queue
         gui_queue = manager.Queue()
         gui_set = manager.list()
-        log_path = Path(data.get("LOG_PATH"),"~/datawork_log")
+        log_path = Path(data.get("LOG_PATH", "~/datawork_log"))
 
         # connect as client, available a server
         server_socket = GNCSocketServer(
             queue_n2t, queue_t2n, address=dw_server_address, log_path=str(log_path/"socket_server"))
-        print("Cliente ===================")
-        print(collector_address)
         client_socket = GNCSocketClient(
            queue_client_n2t, queue_client_t2n, address=collector_address, log_path=str(log_path/"socket_client"))
         enqueued = manager.list()
@@ -383,7 +381,7 @@ def start_datawork(env, conf="collector_example.json"):
 @click.option("--env/--no-env", default=True, show_default=True,  type=bool, required=True,help="Si obtener los datos de ambiente o cargarlos de un json o data entregada")
 @click.option("--conf", default="JSON FILE",  show_default=True, help="Archivo json con los parámetros de configuración")
 def run_datawork(name, env_vars, env, conf):
-    print("Iniciando servicio COLLECTOR para %s" %name.upper())
+    print("Iniciando servicio DATAWORK para %s" %name.upper())
     if env and env_vars:
         envvar = EnvData()
         envvar.show()
